@@ -8,4 +8,4 @@
 void SWP( double **X, int k, int size);
 void dinv(double **X, int size, double **X_inv);
 void dcholdc(double **X, int size, double **L);
-double ddet(double **X, int size);
+double ddet(double **X, int size, int give_log);
